%bcond_without spice

%global _disable_ld_no_undefined 1

%if %{with spice}
%define spice_mode enabled
%else
%define spice_mode disabled
%endif


%define commit 694110ccc3b60b8319237a823c6e7236f88837ec
%define gitrel  %(c=%{commit}; echo ${c:0:7})
%define spicerel 63e382a
%define date 20201207

Summary:	A real-time visual space simulation
Name:		celestia
Version:	1.7.0
Release:	%mkrel -c %{date}git.%{gitrel} 3
License:	GPLv2+
Group:		Sciences/Astronomy
URL:		https://celestia.space/
Source0:	https://api.github.com/repos/CelestiaProject/Celestia/tarball/%{gitrel}#/celestia-1.7.0-git.%{date}.%{gitrel}.tar.gz
Source1:        %{name}.desktop
%if %{with spice}
Source10:       https://api.github.com/repos/OpenSpace/Spice/tarball/%{spicerel}#/cspice-%{spicerel}.tar.gz
%endif
Source11:       celestia.cfg

%if %{with spice}
Patch0: cmake-spice-m64.patch
%endif

BuildRequires:  cmake
BuildRequires:	gettext-devel
BuildRequires:	pkgconfig(glu)
BuildRequires:	pkgconfig(cairo)
BuildRequires:	pkgconfig(theora)
BuildRequires:	pkgconfig(Qt5Concurrent)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5OpenGL)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	pkgconfig(gconf-2.0)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(lua) >= 5.3
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(eigen3)
BuildRequires:	pkgconfig(freeglut)
BuildRequires:  pkgconfig(epoxy)
BuildRequires:  cmake(fmt)
BuildRequires:	desktop-file-utils
BuildRequires:  libstdc++-static-devel
BuildRequires:  luajit-devel
Requires:       %{name}-data >= %{version}

#include a cjk font
Requires:       google-noto-sans-cjk-ttc-fonts

%description
Celestia is a free real-time space simulation that lets you experience
our universe in three dimensions. Unlike most planetarium software,
Celestia doesn't confine you to the surface of the Earth. You can
travel throughout the solar system, to any of over 100,000 stars, or
even beyond the galaxy. All travel in Celestia is seamless; the
exponential zoom feature lets you explore space across a huge range of
scales, from galaxy clusters down to spacecraft only a few meters
across. A 'point-and-goto' interface makes it simple to navigate
through the universe to the object you want to visit.

%package data
Summary:        Real-time 3D visualization of space
Group:          Sciences/Astronomy
Requires:       %{name} >= %{version}
BuildArch:      noarch

%description data
Unlike most planetarium software, Celestia doesn't confine you to the
surface of the Earth. You can travel throughout the solar system, to
any of over 100,000 stars, or even beyond the galaxy.
All movement in Celestia is seamless; the exponential zoom feature lets
you explore space across a huge range of scales, from galaxy clusters
down to spacecraft only a few meters across. A 'point-and-goto'
interface makes it simple to navigate through the universe to the
object you want to visit.
Celestia is expandable. Celestia comes with a large catalog of stars,
galaxies, planets, moons, asteroids, comets, and spacecraft. If that's
not enough, you can download dozens of easy to install add-ons with
more objects.

Data (catalogs, fonts, models, scripts, shaders, textures, ...)
required by Celestia.

%prep
%setup -q -n CelestiaProject-Celestia-%{gitrel}
%if %{with spice}
tar xzf %{SOURCE10}  -C thirdparty
mv thirdparty/OpenSpace-Spice-%{spicerel}/* thirdparty/Spice
%endif
%autopatch -p1
touch content/CMakeLists.txt
echo "add_subdirectory(data)" >> CMakeLists.txt
echo "add_subdirectory(models)" >> CMakeLists.txt
echo "add_subdirectory(textures)" >> CMakeLists.txt


%build
%if %{with spice}
%cmake -DGIT_COMMIT=%{gitrel} -DENABLE_SPICE=ON -DENABLE_GLUT=ON
%else
%cmake -DGIT_COMMIT=%{gitrel} -DENABLE_GLUT=ON
%endif

%cmake_build

%install
%cmake_install

pushd %{_vpath_builddir}/thirdparty/Spice
install -D -m 0755 libSpice.so -t %{buildroot}%{_libdir} 
popd

mv %{buildroot}/%{_bindir}/celestia-qt %{buildroot}/%{_bindir}/celestia

install -p -m 644 -D src/celestia/kde/data/hi48-app-celestia.png \
  %{buildroot}%{_datadir}/pixmaps/celestia.png
cp -r extras %{buildroot}%{_datadir}/%{name}
cp -r extras-standard %{buildroot}%{_datadir}/%{name}

install -D -m 0644 -t %{buildroot}%{_datadir}/applications/ %{SOURCE1}
install -D -m 0644 -t %{buildroot}%{_datadir}/%{name} %{SOURCE11}
install -D -m 0644 -t %{buildroot}%{_datadir}/mimelnk/application/ \
	src/celestia/kde/data/x-%{name}-script.desktop
install -D -m 0644 -t %{buildroot}%{_defaultdocdir}/%{name}/ \
	AUTHORS COPYING ChangeLog README.md

# lang tmp hack
for po_path in po po2; do
    pushd $po_path
    for po_file in $(ls *.po); do
        mo_lang=$(basename $po_file .po)
        mo_path=%{buildroot}%{_datadir}/locale/$mo_lang/LC_MESSAGES
        test $po_path = "po" && mo_name=%{name}.mo || mo_name=%{name}_constellations.mo
        mkdir -p $mo_path
        msgfmt -o $mo_path/$mo_name $po_file
    done
    popd
done


%find_lang %{name}
%find_lang %{name}_constellations
cat %{name}_constellations.lang >> %{name}.lang

#use system ttf fonts
rm -rf %{buildroot}/%{_datadir}/celestia/fonts

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING README controls.txt coding-standards.html
%doc devguide.txt 
%{_bindir}/*
%{_libdir}/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mimelnk/application/x-%{name}-script.desktop
%{_docdir}/%{name}/
%{_datadir}/pixmaps/%{name}.png

%files data
%{_datadir}/%{name}/


%changelog
* Wed Dec 16 2020 umeabot <umeabot> 1.7.0-0.20201207git.694110c.3.mga8
+ Revision: 1658188
- Rebuild for new Qt5

* Mon Dec 07 2020 joequant <joequant> 1.7.0-0.20201207git.694110c.2.mga8
+ Revision: 1654304
- update to latest version

* Wed Dec 02 2020 luigiwalser <luigiwalser> 1.7.0-0.20200809git.acd80d7.2.mga8
+ Revision: 1651342
- rebuild for glew

* Wed Aug 19 2020 joequant <joequant> 1.7.0-0.20200809git.acd80d7.1.mga8
+ Revision: 1615736
- update version

* Mon Jul 13 2020 joequant <joequant> 1.7.0-0.20200713git.82e6106.1.mga8
+ Revision: 1605802
- update to latest

* Thu Jul 02 2020 joequant <joequant> 1.7.0-0.20200624git.9e956ab.2.mga8
+ Revision: 1601358
- compile with luajit

* Mon Jun 29 2020 joequant <joequant> 1.7.0-0.20200624git.9e956ab.1.mga8
+ Revision: 1600339
- update to latest and use system ttf

* Sun Jun 28 2020 joequant <joequant> 1.7.0-0.20200526git.7a062af.2.mga8
+ Revision: 1600121
- add satelites

* Sun Jun 28 2020 joequant <joequant> 1.7.0-0.20200526git.7a062af.1.mga8
+ Revision: 1600099
- add expoxy
- add new commits

* Mon Apr 13 2020 joequant <joequant> 1.7.0-0.20200411git.65541e2.1.mga8
+ Revision: 1567095
- upgrade to latest version

* Sat Apr 04 2020 kekepower <kekepower> 1.7.0-0.20191222git.739f71c.3.mga8
+ Revision: 1564362
- Rebuild for new fmt

* Tue Feb 18 2020 umeabot <umeabot> 1.7.0-0.20191222git.739f71c.2.mga8
+ Revision: 1541535
- Mageia 8 Mass Rebuild

* Sat Dec 28 2019 joequant <joequant> 1.7.0-0.20191222git.739f71c.1.mga8
+ Revision: 1474614
- update to 20191222
+ wally <wally>
- build with new cmake macros

* Fri Oct 11 2019 joequant <joequant> 1.7.0-0.20191009git.17db71b.4.mga8
+ Revision: 1451426
- upgrade to stdc++-fs
- update libstdc++-fs
- update to latest

* Sat Jul 06 2019 kekepower <kekepower> 1.7.0-0.20190423git.920a0c8.3.mga8
+ Revision: 1419117
- Rebuild for new libfmt

* Tue Apr 23 2019 joequant <joequant> 1.7.0-0.20190423git.920a0c8.2.mga7
+ Revision: 1394919
- update to 20190423

* Sat Mar 30 2019 umeabot <umeabot> 1.7.0-0.20190323git.45836d9.2.mga7
+ Revision: 1381423
- Qt5 Rebuild

* Tue Mar 26 2019 joequant <joequant> 1.7.0-0.20190323git.45836d9.1.mga7
+ Revision: 1380389
- update to latest

* Wed Feb 20 2019 joequant <joequant> 1.7.0-0.20190215git.e822651.1.mga7
+ Revision: 1368922
- update to 20190215

* Wed Feb 06 2019 joequant <joequant> 1.7.0-0.20190131git.aea55f5.4.mga7
+ Revision: 1363502
- add icon / use lua 5.3

* Sat Feb 02 2019 joequant <joequant> 1.7.0-0.20190131git.aea55f5.3.mga7
+ Revision: 1362462
- fix extra installation

* Sat Feb 02 2019 joequant <joequant> 1.7.0-0.20190131git.aea55f5.2.mga7
+ Revision: 1362427
- remove m64 flag for spice
- cmake
- add cmake
- add sources
- update version

* Sat Sep 22 2018 umeabot <umeabot> 1.7.0-0.20180123git.120a5ba.1.mga7
+ Revision: 1296284
- Mageia 7 Mass Rebuild
+ joequant <joequant>
- remove m32 option for arm
- sync to github
- fix warning, preference, and lua5.2
- fix for lua 5.2
- update to 1.7.0

* Mon Sep 11 2017 cjw <cjw> 1.6.1-19.mga7
+ Revision: 1152971
- fix for new find_lang

* Sun Jan 03 2016 alexl <alexl> 1.6.1-18.mga6
+ Revision: 919296
- add manpage from Debian
- fix spurious-executable-perm
- s/makeinstall_std/make_install/
- fix %%find_lang twice
- delete %%attr macros
- use icons with transparancy

* Tue Jul 28 2015 alexl <alexl> 1.6.1-17.mga6
+ Revision: 858732
- add translations for desktop file

* Tue Jul 28 2015 alexl <alexl> 1.6.1-16.mga6
+ Revision: 858473
- show localized Controls and Licence (LocaleFilename.patch)
- update POT file after gtk-i18n.patch
- update translations

* Tue Jan 06 2015 alexl <alexl> 1.6.1-15.mga5
+ Revision: 808766
- update desktop file (delete Encoding and add GenericName)

* Thu Dec 18 2014 alexl <alexl> 1.6.1-14.mga5
+ Revision: 803999
- fixed wrong-file-end-of-line-encoding (rpmlint)
- fixed GTK+ ui i18n (mga#14573)

* Wed Oct 15 2014 umeabot <umeabot> 1.6.1-13.mga5
+ Revision: 747962
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.6.1-12.mga5
+ Revision: 678345
- Mageia 5 Mass Rebuild

* Sat Jul 05 2014 tv <tv> 1.6.1-11.mga5
+ Revision: 643848
- actually apply new patches

* Sat Jul 05 2014 tv <tv> 1.6.1-10.mga5
+ Revision: 643847
- add patches from FC in order to fix abort on startup

* Sat Jul 05 2014 tv <tv> 1.6.1-9.mga5
+ Revision: 643687
- rebuild with latest lua (trying to fix startup)

* Tue Jul 01 2014 tv <tv> 1.6.1-8.mga5
+ Revision: 641734
- patch 7: fix build with lua-5.2 (from FC)
- rebuild with lua-5.2

* Sat Oct 19 2013 umeabot <umeabot> 1.6.1-7.mga4
+ Revision: 526048
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 fwang <fwang> 1.6.1-6.mga4
+ Revision: 435813
- more fix
- fix building with libpng 1.6
- rebuild for new libpng

* Fri Jan 11 2013 umeabot <umeabot> 1.6.1-5.mga3
+ Revision: 347557
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 11 2013 cjw <cjw> 1.6.1-4.mga3
+ Revision: 345911
- update po/Makefile.in.in and po2/Makefile.in.in to fix make install
+ fwang <fwang>
- disable schema install
- fix build with automake 1.13

* Mon Jul 30 2012 sander85 <sander85> 1.6.1-3.mga3
+ Revision: 276157
- Add patch from Fedora to fix build with gcc 4.7.
- Switch BR to lua5.1-devel as build with 5.2 fails.

* Thu Dec 29 2011 supp <supp> 1.6.1-2.mga2
+ Revision: 188809
- rebuild for mga2

* Tue Sep 13 2011 fwang <fwang> 1.6.1-1.mga2
+ Revision: 143023
- more link order fix
- fix link order
- fix include of zlib
- new version 1.6.1
- fix as needed build
- fix build with latest libpng
- br png
- rebuild for new libpng

* Wed Mar 09 2011 mikala <mikala> 1.6.0-3.mga1
+ Revision: 66885
- Remove BuildRoot
- Drop mdk macros
- imported package celestia


* Mon Dec 06 2010 Funda Wang <fwang@mandriva.org> 1.6.0-3mdv2011.0
+ Revision: 611370
- add gentoo patch to make it build

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

* Thu Sep 10 2009 Thierry Vignaud <tv@mandriva.org> 1.6.0-2mdv2010.0
+ Revision: 436988
- rebuild

  + Emmanuel Andry <eandry@mandriva.org>
    - BR jpeg-devel
    - New version 1.6.0
    - use GTK frontend to be desktop agnostic
    - drop P0
    - rediff P1 (was P3)
    - add P0 from gentoo to fix GCC44 build

* Sun Nov 23 2008 Funda Wang <fwang@mandriva.org> 1.5.1-3mdv2009.1
+ Revision: 305969
- build gnome frontend
- rediff patch0

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

  + Oden Eriksson <oeriksson@mandriva.com>
    - added a gcc43 patch from fedora

* Wed May 07 2008 Funda Wang <fwang@mandriva.org> 1.5.1-1mdv2009.0
+ Revision: 202885
- New version 1.5.1

* Fri Feb 01 2008 Funda Wang <fwang@mandriva.org> 1.5.0-1mdv2008.1
+ Revision: 161002
- fix desktop file icon
- FIx desktop orig dir
- drop old patches
- add missing file
- New version 1.5.0

  + Thierry Vignaud <tv@mandriva.org>
    - drop old menu

* Wed Dec 26 2007 Oden Eriksson <oeriksson@mandriva.com> 1.4.1-9mdv2008.1
+ Revision: 137975
- rebuilt against openldap-2.4.7 libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Jul 16 2007 Emmanuel Andry <eandry@mandriva.org> 1.4.1-8mdv2008.0
+ Revision: 52746
- rediff patch2
- disable lua, make problems
- update patch2
- added lua support
- added patch 7 for lua
- added patches 2, 3, 4, 5, 6
- fix bugs 24720, 25752, 28572
- drop patch 1

  + Andreas Hasenack <andreas@mandriva.com>
    - rebuild to fix buildroot problem (/usr/share/apps/celestia was pointing to the buildroot)
    - support automake 1.10

  + Olivier Thauvin <nanardon@mandriva.org>
    - rebuild


* Sun Nov 05 2006 Emmanuel Andry <eandry@mandriva.org> 1.4.1-3mdv2007.0
+ Revision: 76781
-fix x86_64 build (bug#25768)
- commit-message

  + Nicolas Lécureuil <neoclust@mandriva.org>
    - celestia-1.4.1-2mdv2007.0
    - Really fix to xdg (and to have menu entry on new menu
      not a bad one)

* Fri Aug 04 2006 Olivier Thauvin <nanardon@mandriva.org> 1.4.1-1mdv2007.0
+ Revision: 43311
- 1.4.1
- xdg menu
- patch fixing c++ and destdir
- Import celestia

